from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Geom2d import *
from OCC.Core.TopTools import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.Law import *

#the following typedef cannot be wrapped as is
ChFiDS_IndexedDataMapOfVertexListOfStripe = NewType('ChFiDS_IndexedDataMapOfVertexListOfStripe', Any)

class ChFiDS_ListOfHElSpine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ChFiDS_ListOfStripe:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ChFiDS_Regularities:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> ChFiDS_Regul: ...
    def Last(self) -> ChFiDS_Regul: ...
    def Append(self, theItem: ChFiDS_Regul) -> ChFiDS_Regul: ...
    def Prepend(self, theItem: ChFiDS_Regul) -> ChFiDS_Regul: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> ChFiDS_Regul: ...
    def SetValue(self, theIndex: int, theValue: ChFiDS_Regul) -> None: ...

class ChFiDS_SecArray1:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> ChFiDS_CircSection: ...
    def __setitem__(self, index: int, value: ChFiDS_CircSection) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[ChFiDS_CircSection]: ...
    def next(self) -> ChFiDS_CircSection: ...
    __next__ = next
    def Init(self, theValue: ChFiDS_CircSection) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> ChFiDS_CircSection: ...
    def Last(self) -> ChFiDS_CircSection: ...
    def Value(self, theIndex: int) -> ChFiDS_CircSection: ...
    def SetValue(self, theIndex: int, theValue: ChFiDS_CircSection) -> None: ...

class ChFiDS_SequenceOfSpine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ChFiDS_SequenceOfSurfData:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ChFiDS_StripeArray1:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ChFiDS_State(IntEnum):
	ChFiDS_OnSame: int = ...
	ChFiDS_OnDiff: int = ...
	ChFiDS_AllSame: int = ...
	ChFiDS_BreakPoint: int = ...
	ChFiDS_FreeBoundary: int = ...
	ChFiDS_Closed: int = ...
	ChFiDS_Tangent: int = ...
ChFiDS_OnSame = ChFiDS_State.ChFiDS_OnSame
ChFiDS_OnDiff = ChFiDS_State.ChFiDS_OnDiff
ChFiDS_AllSame = ChFiDS_State.ChFiDS_AllSame
ChFiDS_BreakPoint = ChFiDS_State.ChFiDS_BreakPoint
ChFiDS_FreeBoundary = ChFiDS_State.ChFiDS_FreeBoundary
ChFiDS_Closed = ChFiDS_State.ChFiDS_Closed
ChFiDS_Tangent = ChFiDS_State.ChFiDS_Tangent

class ChFiDS_ChamfMethod(IntEnum):
	ChFiDS_Sym: int = ...
	ChFiDS_TwoDist: int = ...
	ChFiDS_DistAngle: int = ...
ChFiDS_Sym = ChFiDS_ChamfMethod.ChFiDS_Sym
ChFiDS_TwoDist = ChFiDS_ChamfMethod.ChFiDS_TwoDist
ChFiDS_DistAngle = ChFiDS_ChamfMethod.ChFiDS_DistAngle

class ChFiDS_ChamfMode(IntEnum):
	ChFiDS_ClassicChamfer: int = ...
	ChFiDS_ConstThroatChamfer: int = ...
	ChFiDS_ConstThroatWithPenetrationChamfer: int = ...
ChFiDS_ClassicChamfer = ChFiDS_ChamfMode.ChFiDS_ClassicChamfer
ChFiDS_ConstThroatChamfer = ChFiDS_ChamfMode.ChFiDS_ConstThroatChamfer
ChFiDS_ConstThroatWithPenetrationChamfer = ChFiDS_ChamfMode.ChFiDS_ConstThroatWithPenetrationChamfer

class ChFiDS_ErrorStatus(IntEnum):
	ChFiDS_Ok: int = ...
	ChFiDS_Error: int = ...
	ChFiDS_WalkingFailure: int = ...
	ChFiDS_StartsolFailure: int = ...
	ChFiDS_TwistedSurface: int = ...
ChFiDS_Ok = ChFiDS_ErrorStatus.ChFiDS_Ok
ChFiDS_Error = ChFiDS_ErrorStatus.ChFiDS_Error
ChFiDS_WalkingFailure = ChFiDS_ErrorStatus.ChFiDS_WalkingFailure
ChFiDS_StartsolFailure = ChFiDS_ErrorStatus.ChFiDS_StartsolFailure
ChFiDS_TwistedSurface = ChFiDS_ErrorStatus.ChFiDS_TwistedSurface

class ChFiDS_TypeOfConcavity(IntEnum):
	ChFiDS_Concave: int = ...
	ChFiDS_Convex: int = ...
	ChFiDS_Tangential: int = ...
	ChFiDS_FreeBound: int = ...
	ChFiDS_Other: int = ...
ChFiDS_Concave = ChFiDS_TypeOfConcavity.ChFiDS_Concave
ChFiDS_Convex = ChFiDS_TypeOfConcavity.ChFiDS_Convex
ChFiDS_Tangential = ChFiDS_TypeOfConcavity.ChFiDS_Tangential
ChFiDS_FreeBound = ChFiDS_TypeOfConcavity.ChFiDS_FreeBound
ChFiDS_Other = ChFiDS_TypeOfConcavity.ChFiDS_Other

class ChFiDS_CircSection:
	def __init__(self) -> None: ...
	@overload
	def Get(self, C: gp_Circ) -> Tuple[float, float]: ...
	@overload
	def Get(self, C: gp_Lin) -> Tuple[float, float]: ...
	@overload
	def Set(self, C: gp_Circ, F: float, L: float) -> None: ...
	@overload
	def Set(self, C: gp_Lin, F: float, L: float) -> None: ...

class ChFiDS_CommonPoint:
	def __init__(self) -> None: ...
	def Arc(self) -> TopoDS_Edge: ...
	def HasVector(self) -> bool: ...
	def IsOnArc(self) -> bool: ...
	def IsVertex(self) -> bool: ...
	def Parameter(self) -> float: ...
	def ParameterOnArc(self) -> float: ...
	def Point(self) -> gp_Pnt: ...
	def Reset(self) -> None: ...
	def SetArc(self, Tol: float, A: TopoDS_Edge, Param: float, TArc: TopAbs_Orientation) -> None: ...
	def SetParameter(self, Param: float) -> None: ...
	def SetPoint(self, thePoint: gp_Pnt) -> None: ...
	def SetTolerance(self, Tol: float) -> None: ...
	def SetVector(self, theVector: gp_Vec) -> None: ...
	def SetVertex(self, theVertex: TopoDS_Vertex) -> None: ...
	def Tolerance(self) -> float: ...
	def TransitionOnArc(self) -> TopAbs_Orientation: ...
	def Vector(self) -> gp_Vec: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class ChFiDS_ElSpine(Adaptor3d_Curve):
	def __init__(self) -> None: ...
	def AddVertexWithTangent(self, anAx1: gp_Ax1) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def ChangeNext(self) -> ChFiDS_SurfData: ...
	def ChangePrevious(self) -> ChFiDS_SurfData: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, AbsC: float, P: gp_Pnt) -> None: ...
	def D1(self, AbsC: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, AbsC: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, AbsC: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def Ellipse(self) -> gp_Elips: ...
	@overload
	def FirstParameter(self) -> float: ...
	@overload
	def FirstParameter(self, P: float) -> None: ...
	def FirstPointAndTgt(self, P: gp_Pnt, T: gp_Vec) -> None: ...
	def GetSavedFirstParameter(self) -> float: ...
	def GetSavedLastParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsPeriodic(self) -> bool: ...
	@overload
	def LastParameter(self) -> float: ...
	@overload
	def LastParameter(self, P: float) -> None: ...
	def LastPointAndTgt(self, P: gp_Pnt, T: gp_Vec) -> None: ...
	def Line(self) -> gp_Lin: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVertices(self) -> int: ...
	def Next(self) -> ChFiDS_SurfData: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Previous(self) -> ChFiDS_SurfData: ...
	def Resolution(self, R3d: float) -> float: ...
	def SaveFirstParameter(self) -> None: ...
	def SaveLastParameter(self) -> None: ...
	def SetCurve(self, C: Geom_Curve) -> None: ...
	def SetFirstPointAndTgt(self, P: gp_Pnt, T: gp_Vec) -> None: ...
	def SetLastPointAndTgt(self, P: gp_Pnt, T: gp_Vec) -> None: ...
	def SetOrigin(self, O: float) -> None: ...
	def SetPeriodic(self, I: bool) -> None: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, AbsC: float) -> gp_Pnt: ...
	def VertexWithTangent(self, Index: int) -> gp_Ax1: ...

class ChFiDS_FaceInterference:
	def __init__(self) -> None: ...
	def ChangePCurveOnFace(self) -> Geom2d_Curve: ...
	def ChangePCurveOnSurf(self) -> Geom2d_Curve: ...
	def FirstParameter(self) -> float: ...
	def LastParameter(self) -> float: ...
	def LineIndex(self) -> int: ...
	def PCurveOnFace(self) -> Geom2d_Curve: ...
	def PCurveOnSurf(self) -> Geom2d_Curve: ...
	def Parameter(self, IsFirst: bool) -> float: ...
	def SetFirstParameter(self, U1: float) -> None: ...
	def SetInterference(self, LineIndex: int, Trans: TopAbs_Orientation, PCurv1: Geom2d_Curve, PCurv2: Geom2d_Curve) -> None: ...
	def SetLastParameter(self, U1: float) -> None: ...
	def SetLineIndex(self, I: int) -> None: ...
	def SetParameter(self, U1: float, IsFirst: bool) -> None: ...
	def SetTransition(self, Trans: TopAbs_Orientation) -> None: ...
	def Transition(self) -> TopAbs_Orientation: ...

class ChFiDS_HElSpine(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: ChFiDS_ElSpine) -> None: ...
	def ChangeCurve(self) -> ChFiDS_ElSpine: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: ChFiDS_ElSpine) -> None: ...

class ChFiDS_Map:
	def __init__(self) -> None: ...
	def Contains(self, S: TopoDS_Shape) -> bool: ...
	def Fill(self, S: TopoDS_Shape, T1: TopAbs_ShapeEnum, T2: TopAbs_ShapeEnum) -> None: ...
	def FindFromIndex(self, I: int) -> TopTools_ListOfShape: ...
	def FindFromKey(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...

class ChFiDS_Regul:
	def __init__(self) -> None: ...
	def Curve(self) -> int: ...
	def IsSurface1(self) -> bool: ...
	def IsSurface2(self) -> bool: ...
	def S1(self) -> int: ...
	def S2(self) -> int: ...
	def SetCurve(self, IC: int) -> None: ...
	def SetS1(self, IS1: int, IsFace: Optional[bool] = True) -> None: ...
	def SetS2(self, IS2: int, IsFace: Optional[bool] = True) -> None: ...

class ChFiDS_Spine(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Tol: float) -> None: ...
	@overload
	def Absc(self, U: float) -> float: ...
	@overload
	def Absc(self, U: float, I: int) -> float: ...
	@overload
	def Absc(self, V: TopoDS_Vertex) -> float: ...
	def AppendElSpine(self, Els: ChFiDS_HElSpine) -> None: ...
	def AppendOffsetElSpine(self, Els: ChFiDS_HElSpine) -> None: ...
	def ChangeElSpines(self) -> ChFiDS_ListOfHElSpine: ...
	def ChangeOffsetElSpines(self) -> ChFiDS_ListOfHElSpine: ...
	def Circle(self) -> gp_Circ: ...
	def CurrentElementarySpine(self, Index: int) -> BRepAdaptor_Curve: ...
	def CurrentIndexOfElementarySpine(self) -> int: ...
	def D0(self, AbsC: float, P: gp_Pnt) -> None: ...
	def D1(self, AbsC: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, AbsC: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def Edges(self, I: int) -> TopoDS_Edge: ...
	@overload
	def ElSpine(self, IE: int) -> ChFiDS_HElSpine: ...
	@overload
	def ElSpine(self, E: TopoDS_Edge) -> ChFiDS_HElSpine: ...
	@overload
	def ElSpine(self, W: float) -> ChFiDS_HElSpine: ...
	def ErrorStatus(self) -> ChFiDS_ErrorStatus: ...
	@overload
	def FirstParameter(self) -> float: ...
	@overload
	def FirstParameter(self, IndexSpine: int) -> float: ...
	def FirstStatus(self) -> ChFiDS_State: ...
	def FirstVertex(self) -> TopoDS_Vertex: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def GetTypeOfConcavity(self) -> ChFiDS_TypeOfConcavity: ...
	def HasFirstTgt(self) -> bool: ...
	def HasLastTgt(self) -> bool: ...
	@overload
	def Index(self, W: float, Forward: Optional[bool] = True) -> int: ...
	@overload
	def Index(self, E: TopoDS_Edge) -> int: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsTangencyExtremity(self, IsFirst: bool) -> bool: ...
	@overload
	def LastParameter(self) -> float: ...
	@overload
	def LastParameter(self, IndexSpine: int) -> float: ...
	def LastStatus(self) -> ChFiDS_State: ...
	def LastVertex(self) -> TopoDS_Vertex: ...
	def Length(self, IndexSpine: int) -> float: ...
	def Line(self) -> gp_Lin: ...
	def Load(self) -> None: ...
	def Mode(self) -> ChFiDS_ChamfMode: ...
	def NbEdges(self) -> int: ...
	def OffsetEdges(self, I: int) -> TopoDS_Edge: ...
	@overload
	def Parameter(self, AbsC: float, Oriented: Optional[bool] = True) -> float: ...
	@overload
	def Parameter(self, Index: int, AbsC: float, Oriented: Optional[bool] = True) -> float: ...
	def Period(self) -> float: ...
	def PutInFirst(self, E: TopoDS_Edge) -> None: ...
	def PutInFirstOffset(self, E: TopoDS_Edge) -> None: ...
	def Reset(self, AllData: Optional[bool] = False) -> None: ...
	def Resolution(self, R3d: float) -> float: ...
	def SetCurrent(self, Index: int) -> None: ...
	def SetEdges(self, E: TopoDS_Edge) -> None: ...
	def SetErrorStatus(self, state: ChFiDS_ErrorStatus) -> None: ...
	def SetFirstParameter(self, Par: float) -> None: ...
	def SetFirstStatus(self, S: ChFiDS_State) -> None: ...
	def SetFirstTgt(self, W: float) -> None: ...
	def SetLastParameter(self, Par: float) -> None: ...
	def SetLastStatus(self, S: ChFiDS_State) -> None: ...
	def SetLastTgt(self, W: float) -> None: ...
	def SetOffsetEdges(self, E: TopoDS_Edge) -> None: ...
	@overload
	def SetReference(self, W: float) -> None: ...
	@overload
	def SetReference(self, I: int) -> None: ...
	def SetStatus(self, S: ChFiDS_State, IsFirst: bool) -> None: ...
	def SetTangencyExtremity(self, IsTangency: bool, IsFirst: bool) -> None: ...
	def SetTypeOfConcavity(self, theType: ChFiDS_TypeOfConcavity) -> None: ...
	@overload
	def SplitDone(self) -> bool: ...
	@overload
	def SplitDone(self, B: bool) -> None: ...
	def Status(self, IsFirst: bool) -> ChFiDS_State: ...
	def UnsetReference(self) -> None: ...
	def Value(self, AbsC: float) -> gp_Pnt: ...

class ChFiDS_Stripe(Standard_Transient):
	def __init__(self) -> None: ...
	def ChangeFirstCurve(self, Index: int) -> None: ...
	def ChangeFirstPCurve(self) -> Geom2d_Curve: ...
	def ChangeFirstParameters(self, Pdeb: float, Pfin: float) -> None: ...
	def ChangeIndexFirstPointOnS1(self, Index: int) -> None: ...
	def ChangeIndexFirstPointOnS2(self, Index: int) -> None: ...
	def ChangeIndexLastPointOnS1(self, Index: int) -> None: ...
	def ChangeIndexLastPointOnS2(self, Index: int) -> None: ...
	def ChangeLastCurve(self, Index: int) -> None: ...
	def ChangeLastPCurve(self) -> Geom2d_Curve: ...
	def ChangeLastParameters(self, Pdeb: float, Pfin: float) -> None: ...
	def ChangePCurve(self, First: bool) -> Geom2d_Curve: ...
	def ChangeSetOfSurfData(self) -> ChFiDS_HData: ...
	def ChangeSpine(self) -> ChFiDS_Spine: ...
	@overload
	def Choix(self) -> int: ...
	@overload
	def Choix(self, C: int) -> None: ...
	def Curve(self, First: bool) -> int: ...
	def FirstCurve(self) -> int: ...
	def FirstPCurve(self) -> Geom2d_Curve: ...
	@overload
	def FirstPCurveOrientation(self) -> TopAbs_Orientation: ...
	@overload
	def FirstPCurveOrientation(self, O: TopAbs_Orientation) -> None: ...
	def FirstParameters(self) -> Tuple[float, float]: ...
	def InDS(self, First: bool, Nb: Optional[int] = 1) -> None: ...
	def IndexFirstPointOnS1(self) -> int: ...
	def IndexFirstPointOnS2(self) -> int: ...
	def IndexLastPointOnS1(self) -> int: ...
	def IndexLastPointOnS2(self) -> int: ...
	def IndexPoint(self, First: bool, OnS: int) -> int: ...
	def IsInDS(self, First: bool) -> int: ...
	def LastCurve(self) -> int: ...
	def LastPCurve(self) -> Geom2d_Curve: ...
	@overload
	def LastPCurveOrientation(self) -> TopAbs_Orientation: ...
	@overload
	def LastPCurveOrientation(self, O: TopAbs_Orientation) -> None: ...
	def LastParameters(self) -> Tuple[float, float]: ...
	@overload
	def Orientation(self, OnS: int) -> TopAbs_Orientation: ...
	@overload
	def Orientation(self, First: bool) -> TopAbs_Orientation: ...
	@overload
	def OrientationOnFace1(self) -> TopAbs_Orientation: ...
	@overload
	def OrientationOnFace1(self, Or1: TopAbs_Orientation) -> None: ...
	@overload
	def OrientationOnFace2(self) -> TopAbs_Orientation: ...
	@overload
	def OrientationOnFace2(self, Or2: TopAbs_Orientation) -> None: ...
	def PCurve(self, First: bool) -> Geom2d_Curve: ...
	def Parameters(self, First: bool) -> Tuple[float, float]: ...
	def Reset(self) -> None: ...
	def SetCurve(self, Index: int, First: bool) -> None: ...
	def SetIndexPoint(self, Index: int, First: bool, OnS: int) -> None: ...
	def SetOfSurfData(self) -> ChFiDS_HData: ...
	@overload
	def SetOrientation(self, Or: TopAbs_Orientation, OnS: int) -> None: ...
	@overload
	def SetOrientation(self, Or: TopAbs_Orientation, First: bool) -> None: ...
	def SetParameters(self, First: bool, Pdeb: float, Pfin: float) -> None: ...
	def SetSolidIndex(self, Index: int) -> None: ...
	def SolidIndex(self) -> int: ...
	def Spine(self) -> ChFiDS_Spine: ...

class ChFiDS_StripeMap:
	def __init__(self) -> None: ...
	def Add(self, V: TopoDS_Vertex, F: ChFiDS_Stripe) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def FindFromIndex(self, I: int) -> ChFiDS_ListOfStripe: ...
	def FindFromKey(self, V: TopoDS_Vertex) -> ChFiDS_ListOfStripe: ...
	def FindKey(self, I: int) -> TopoDS_Vertex: ...

class ChFiDS_SurfData(Standard_Transient):
	def __init__(self) -> None: ...
	def ChangeIndexOfS1(self, Index: int) -> None: ...
	def ChangeIndexOfS2(self, Index: int) -> None: ...
	def ChangeInterference(self, OnS: int) -> ChFiDS_FaceInterference: ...
	def ChangeInterferenceOnS1(self) -> ChFiDS_FaceInterference: ...
	def ChangeInterferenceOnS2(self) -> ChFiDS_FaceInterference: ...
	def ChangeOrientation(self) -> TopAbs_Orientation: ...
	def ChangeSurf(self, Index: int) -> None: ...
	def ChangeVertex(self, First: bool, OnS: int) -> ChFiDS_CommonPoint: ...
	def ChangeVertexFirstOnS1(self) -> ChFiDS_CommonPoint: ...
	def ChangeVertexFirstOnS2(self) -> ChFiDS_CommonPoint: ...
	def ChangeVertexLastOnS1(self) -> ChFiDS_CommonPoint: ...
	def ChangeVertexLastOnS2(self) -> ChFiDS_CommonPoint: ...
	def Copy(self, Other: ChFiDS_SurfData) -> None: ...
	@overload
	def FirstExtensionValue(self) -> float: ...
	@overload
	def FirstExtensionValue(self, Extend: float) -> None: ...
	@overload
	def FirstSpineParam(self) -> float: ...
	@overload
	def FirstSpineParam(self, Par: float) -> None: ...
	@overload
	def Get2dPoints(self, First: bool, OnS: int) -> gp_Pnt2d: ...
	@overload
	def Get2dPoints(self, P2df1: gp_Pnt2d, P2dl1: gp_Pnt2d, P2df2: gp_Pnt2d, P2dl2: gp_Pnt2d) -> None: ...
	def Index(self, OfS: int) -> int: ...
	def IndexOfC(self, OnS: int) -> int: ...
	def IndexOfC1(self) -> int: ...
	def IndexOfC2(self) -> int: ...
	def IndexOfS1(self) -> int: ...
	def IndexOfS2(self) -> int: ...
	def Interference(self, OnS: int) -> ChFiDS_FaceInterference: ...
	def InterferenceOnS1(self) -> ChFiDS_FaceInterference: ...
	def InterferenceOnS2(self) -> ChFiDS_FaceInterference: ...
	def IsOnCurve(self, OnS: int) -> bool: ...
	def IsOnCurve1(self) -> bool: ...
	def IsOnCurve2(self) -> bool: ...
	@overload
	def LastExtensionValue(self) -> float: ...
	@overload
	def LastExtensionValue(self, Extend: float) -> None: ...
	@overload
	def LastSpineParam(self) -> float: ...
	@overload
	def LastSpineParam(self, Par: float) -> None: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def ResetSimul(self) -> None: ...
	def Set2dPoints(self, P2df1: gp_Pnt2d, P2dl1: gp_Pnt2d, P2df2: gp_Pnt2d, P2dl2: gp_Pnt2d) -> None: ...
	def SetIndexOfC1(self, Index: int) -> None: ...
	def SetIndexOfC2(self, Index: int) -> None: ...
	def SetSimul(self, S: Standard_Transient) -> None: ...
	def Simul(self) -> Standard_Transient: ...
	def Surf(self) -> int: ...
	@overload
	def TwistOnS1(self) -> bool: ...
	@overload
	def TwistOnS1(self, T: bool) -> None: ...
	@overload
	def TwistOnS2(self) -> bool: ...
	@overload
	def TwistOnS2(self, T: bool) -> None: ...
	def Vertex(self, First: bool, OnS: int) -> ChFiDS_CommonPoint: ...
	def VertexFirstOnS1(self) -> ChFiDS_CommonPoint: ...
	def VertexFirstOnS2(self) -> ChFiDS_CommonPoint: ...
	def VertexLastOnS1(self) -> ChFiDS_CommonPoint: ...
	def VertexLastOnS2(self) -> ChFiDS_CommonPoint: ...

class ChFiDS_ChamfSpine(ChFiDS_Spine):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Tol: float) -> None: ...
	def Dists(self) -> Tuple[float, float]: ...
	def GetDist(self) -> float: ...
	def GetDistAngle(self) -> Tuple[float, float]: ...
	def IsChamfer(self) -> ChFiDS_ChamfMethod: ...
	def SetDist(self, Dis: float) -> None: ...
	def SetDistAngle(self, Dis: float, Angle: float) -> None: ...
	def SetDists(self, Dis1: float, Dis2: float) -> None: ...
	def SetMode(self, theMode: ChFiDS_ChamfMode) -> None: ...

class ChFiDS_FilSpine(ChFiDS_Spine):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Tol: float) -> None: ...
	def AppendElSpine(self, Els: ChFiDS_HElSpine) -> None: ...
	def ChangeLaw(self, E: TopoDS_Edge) -> Law_Function: ...
	@overload
	def IsConstant(self) -> bool: ...
	@overload
	def IsConstant(self, IE: int) -> bool: ...
	def Law(self, Els: ChFiDS_HElSpine) -> Law_Composite: ...
	def MaxRadFromSeqAndLaws(self) -> float: ...
	@overload
	def Radius(self) -> float: ...
	@overload
	def Radius(self, IE: int) -> float: ...
	@overload
	def Radius(self, E: TopoDS_Edge) -> float: ...
	def Reset(self, AllData: Optional[bool] = False) -> None: ...
	@overload
	def SetRadius(self, Radius: float, E: TopoDS_Edge) -> None: ...
	@overload
	def SetRadius(self, Radius: float, V: TopoDS_Vertex) -> None: ...
	@overload
	def SetRadius(self, UandR: gp_XY, IinC: int) -> None: ...
	@overload
	def SetRadius(self, Radius: float) -> None: ...
	@overload
	def SetRadius(self, C: Law_Function, IinC: int) -> None: ...
	@overload
	def UnSetRadius(self, E: TopoDS_Edge) -> None: ...
	@overload
	def UnSetRadius(self, V: TopoDS_Vertex) -> None: ...

# harray1 classes

class ChFiDS_SecHArray1(ChFiDS_SecArray1, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> ChFiDS_SecArray1: ...

# harray2 classes
# hsequence classes

class ChFiDS_HData(ChFiDS_SequenceOfSurfData, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: ChFiDS_SequenceOfSurfData) -> None: ...
    def Sequence(self) -> ChFiDS_SequenceOfSurfData: ...
    def Append(self, theSequence: ChFiDS_SequenceOfSurfData) -> None: ...





from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.TCollection import *
from OCC.Core.TDF import *
from OCC.Core.Storage import *

BinObjMgt_PByte = NewType('BinObjMgt_PByte', Standard_Byte)
BinObjMgt_PChar = NewType('BinObjMgt_PChar', str)
BinObjMgt_PExtChar = NewType('BinObjMgt_PExtChar', str)
BinObjMgt_PInteger = NewType('BinObjMgt_PInteger', Standard_Integer)
BinObjMgt_PReal = NewType('BinObjMgt_PReal', Standard_Real)
BinObjMgt_PShortReal = NewType('BinObjMgt_PShortReal', Standard_ShortReal)
BinObjMgt_SRelocationTable = NewType('BinObjMgt_SRelocationTable', TColStd_IndexedMapOfTransient)

class BinObjMgt_Persistent:
	@overload
	def __init__(self) -> None: ...
	def Destroy(self) -> None: ...
	def GetAsciiString(self, theValue: TCollection_AsciiString) -> BinObjMgt_Persistent: ...
	def GetBoolean(self) -> Tuple[BinObjMgt_Persistent, bool]: ...
	def GetByte(self, theValue: str) -> BinObjMgt_Persistent: ...
	def GetByteArray(self, theArray: BinObjMgt_PByte, theLength: int) -> BinObjMgt_Persistent: ...
	def GetCharArray(self, theArray: BinObjMgt_PChar, theLength: int) -> BinObjMgt_Persistent: ...
	def GetCharacter(self, theValue: str) -> BinObjMgt_Persistent: ...
	def GetExtCharArray(self, theArray: BinObjMgt_PExtChar, theLength: int) -> BinObjMgt_Persistent: ...
	def GetExtCharacter(self, theValue: Standard_ExtCharacter) -> BinObjMgt_Persistent: ...
	def GetExtendedString(self, theValue: TCollection_ExtendedString) -> BinObjMgt_Persistent: ...
	def GetGUID(self, theValue: Standard_GUID) -> BinObjMgt_Persistent: ...
	def GetIntArray(self, theArray: BinObjMgt_PInteger, theLength: int) -> BinObjMgt_Persistent: ...
	def GetInteger(self) -> Tuple[BinObjMgt_Persistent, int]: ...
	def GetLabel(self, theDS: TDF_Data, theValue: TDF_Label) -> BinObjMgt_Persistent: ...
	def GetReal(self) -> Tuple[BinObjMgt_Persistent, float]: ...
	def GetRealArray(self, theArray: BinObjMgt_PReal, theLength: int) -> BinObjMgt_Persistent: ...
	def GetShortReal(self, theValue: float) -> BinObjMgt_Persistent: ...
	def GetShortRealArray(self, theArray: BinObjMgt_PShortReal, theLength: int) -> BinObjMgt_Persistent: ...
	def Id(self) -> int: ...
	def Init(self) -> None: ...
	def IsError(self) -> bool: ...
	def IsOK(self) -> bool: ...
	def Length(self) -> int: ...
	def Position(self) -> int: ...
	def PutAsciiString(self, theValue: TCollection_AsciiString) -> BinObjMgt_Persistent: ...
	def PutBoolean(self, theValue: bool) -> BinObjMgt_Persistent: ...
	def PutByte(self, theValue: str) -> BinObjMgt_Persistent: ...
	def PutByteArray(self, theArray: BinObjMgt_PByte, theLength: int) -> BinObjMgt_Persistent: ...
	def PutCString(self, theValue: str) -> BinObjMgt_Persistent: ...
	def PutCharArray(self, theArray: BinObjMgt_PChar, theLength: int) -> BinObjMgt_Persistent: ...
	def PutCharacter(self, theValue: str) -> BinObjMgt_Persistent: ...
	def PutExtCharArray(self, theArray: BinObjMgt_PExtChar, theLength: int) -> BinObjMgt_Persistent: ...
	def PutExtCharacter(self, theValue: Standard_ExtCharacter) -> BinObjMgt_Persistent: ...
	def PutExtendedString(self, theValue: TCollection_ExtendedString) -> BinObjMgt_Persistent: ...
	def PutGUID(self, theValue: Standard_GUID) -> BinObjMgt_Persistent: ...
	def PutIntArray(self, theArray: BinObjMgt_PInteger, theLength: int) -> BinObjMgt_Persistent: ...
	def PutInteger(self, theValue: int) -> BinObjMgt_Persistent: ...
	def PutLabel(self, theValue: TDF_Label) -> BinObjMgt_Persistent: ...
	def PutReal(self, theValue: float) -> BinObjMgt_Persistent: ...
	def PutRealArray(self, theArray: BinObjMgt_PReal, theLength: int) -> BinObjMgt_Persistent: ...
	def PutShortReal(self, theValue: float) -> BinObjMgt_Persistent: ...
	def PutShortRealArray(self, theArray: BinObjMgt_PShortReal, theLength: int) -> BinObjMgt_Persistent: ...
	def SetId(self, theId: int) -> None: ...
	def SetPosition(self, thePos: int) -> bool: ...
	def SetTypeId(self, theId: int) -> None: ...
	def Truncate(self) -> None: ...
	def TypeId(self) -> int: ...

class BinObjMgt_RRelocationTable(TColStd_DataMapOfIntegerTransient):
	def Clear(self, doReleaseMemory: Optional[bool] = True) -> None: ...
	def GetHeaderData(self) -> Storage_HeaderData: ...
	def SetHeaderData(self, theHeaderData: Storage_HeaderData) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.TopTools import *

TopExp_Stack = NewType('TopExp_Stack', TopoDS_Iterator)

class topexp:
	@staticmethod
	def CommonVertex(E1: TopoDS_Edge, E2: TopoDS_Edge, V: TopoDS_Vertex) -> bool: ...
	@staticmethod
	def FirstVertex(E: TopoDS_Edge, CumOri: Optional[bool] = False) -> TopoDS_Vertex: ...
	@staticmethod
	def LastVertex(E: TopoDS_Edge, CumOri: Optional[bool] = False) -> TopoDS_Vertex: ...
	@overload
	@staticmethod
	def MapShapes(S: TopoDS_Shape, T: TopAbs_ShapeEnum, M: TopTools_IndexedMapOfShape) -> None: ...
	@overload
	@staticmethod
	def MapShapes(S: TopoDS_Shape, M: TopTools_IndexedMapOfShape) -> None: ...
	@overload
	@staticmethod
	def MapShapes(S: TopoDS_Shape, M: TopTools_MapOfShape) -> None: ...
	@staticmethod
	def MapShapesAndAncestors(S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: TopAbs_ShapeEnum, M: TopTools_IndexedDataMapOfShapeListOfShape) -> None: ...
	@staticmethod
	def MapShapesAndUniqueAncestors(S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: TopAbs_ShapeEnum, M: TopTools_IndexedDataMapOfShapeListOfShape, useOrientation: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def Vertices(E: TopoDS_Edge, Vfirst: TopoDS_Vertex, Vlast: TopoDS_Vertex, CumOri: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def Vertices(W: TopoDS_Wire, Vfirst: TopoDS_Vertex, Vlast: TopoDS_Vertex) -> None: ...

class TopExp_Explorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, ToFind: TopAbs_ShapeEnum, ToAvoid: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def Clear(self) -> None: ...
	def Current(self) -> TopoDS_Shape: ...
	def Depth(self) -> int: ...
	def Destroy(self) -> None: ...
	def Init(self, S: TopoDS_Shape, ToFind: TopAbs_ShapeEnum, ToAvoid: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def ReInit(self) -> None: ...
	def Value(self) -> TopoDS_Shape: ...

# harray1 classes
# harray2 classes
# hsequence classes

topexp_CommonVertex = topexp.CommonVertex
topexp_FirstVertex = topexp.FirstVertex
topexp_LastVertex = topexp.LastVertex
topexp_MapShapes = topexp.MapShapes
topexp_MapShapes = topexp.MapShapes
topexp_MapShapes = topexp.MapShapes
topexp_MapShapesAndAncestors = topexp.MapShapesAndAncestors
topexp_MapShapesAndUniqueAncestors = topexp.MapShapesAndUniqueAncestors
topexp_Vertices = topexp.Vertices
topexp_Vertices = topexp.Vertices



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TColGeom module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_tcolgeom.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TColGeom
else:
    import _TColGeom

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TColGeom.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TColGeom.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TColGeom.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TColGeom.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TColGeom.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TColGeom.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TColGeom.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TColGeom.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TColGeom:
_TColGeom.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TColGeom.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TColGeom_HArray1OfSurface_Create() -> "opencascade::handle< TColGeom_HArray1OfSurface >":
    return _TColGeom.Handle_TColGeom_HArray1OfSurface_Create()

def Handle_TColGeom_HArray1OfSurface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HArray1OfSurface >":
    return _TColGeom.Handle_TColGeom_HArray1OfSurface_DownCast(t)

def Handle_TColGeom_HArray1OfSurface_IsNull(t: "opencascade::handle< TColGeom_HArray1OfSurface > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HArray1OfSurface_IsNull(t)

def Handle_TColGeom_HArray1OfBezierCurve_Create() -> "opencascade::handle< TColGeom_HArray1OfBezierCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfBezierCurve_Create()

def Handle_TColGeom_HArray1OfBezierCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HArray1OfBezierCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfBezierCurve_DownCast(t)

def Handle_TColGeom_HArray1OfBezierCurve_IsNull(t: "opencascade::handle< TColGeom_HArray1OfBezierCurve > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HArray1OfBezierCurve_IsNull(t)

def Handle_TColGeom_HArray1OfBSplineCurve_Create() -> "opencascade::handle< TColGeom_HArray1OfBSplineCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfBSplineCurve_Create()

def Handle_TColGeom_HArray1OfBSplineCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HArray1OfBSplineCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfBSplineCurve_DownCast(t)

def Handle_TColGeom_HArray1OfBSplineCurve_IsNull(t: "opencascade::handle< TColGeom_HArray1OfBSplineCurve > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HArray1OfBSplineCurve_IsNull(t)

def Handle_TColGeom_HArray1OfCurve_Create() -> "opencascade::handle< TColGeom_HArray1OfCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfCurve_Create()

def Handle_TColGeom_HArray1OfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HArray1OfCurve >":
    return _TColGeom.Handle_TColGeom_HArray1OfCurve_DownCast(t)

def Handle_TColGeom_HArray1OfCurve_IsNull(t: "opencascade::handle< TColGeom_HArray1OfCurve > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HArray1OfCurve_IsNull(t)

def Handle_TColGeom_HArray2OfSurface_Create() -> "opencascade::handle< TColGeom_HArray2OfSurface >":
    return _TColGeom.Handle_TColGeom_HArray2OfSurface_Create()

def Handle_TColGeom_HArray2OfSurface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HArray2OfSurface >":
    return _TColGeom.Handle_TColGeom_HArray2OfSurface_DownCast(t)

def Handle_TColGeom_HArray2OfSurface_IsNull(t: "opencascade::handle< TColGeom_HArray2OfSurface > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HArray2OfSurface_IsNull(t)

def Handle_TColGeom_HSequenceOfBoundedCurve_Create() -> "opencascade::handle< TColGeom_HSequenceOfBoundedCurve >":
    return _TColGeom.Handle_TColGeom_HSequenceOfBoundedCurve_Create()

def Handle_TColGeom_HSequenceOfBoundedCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HSequenceOfBoundedCurve >":
    return _TColGeom.Handle_TColGeom_HSequenceOfBoundedCurve_DownCast(t)

def Handle_TColGeom_HSequenceOfBoundedCurve_IsNull(t: "opencascade::handle< TColGeom_HSequenceOfBoundedCurve > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HSequenceOfBoundedCurve_IsNull(t)

def Handle_TColGeom_HSequenceOfCurve_Create() -> "opencascade::handle< TColGeom_HSequenceOfCurve >":
    return _TColGeom.Handle_TColGeom_HSequenceOfCurve_Create()

def Handle_TColGeom_HSequenceOfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom_HSequenceOfCurve >":
    return _TColGeom.Handle_TColGeom_HSequenceOfCurve_DownCast(t)

def Handle_TColGeom_HSequenceOfCurve_IsNull(t: "opencascade::handle< TColGeom_HSequenceOfCurve > const &") -> "bool":
    return _TColGeom.Handle_TColGeom_HSequenceOfCurve_IsNull(t)
class TColGeom_Array1OfBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > >::iterator":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > >::iterator":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_Array1OfBSplineCurve_swiginit(self, _TColGeom.new_TColGeom_Array1OfBSplineCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom_BSplineCurve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom_BSplineCurve > > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom_BSplineCurve > const &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_BSplineCurve > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_BSplineCurve > const &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_BSplineCurve > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BSplineCurve > const &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BSplineCurve > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_BSplineCurve > &":
        return _TColGeom.TColGeom_Array1OfBSplineCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_BSplineCurve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom.TColGeom_Array1OfBSplineCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array1OfBSplineCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom_Array1OfBSplineCurve in _TColGeom:
_TColGeom.TColGeom_Array1OfBSplineCurve_swigregister(TColGeom_Array1OfBSplineCurve)

class TColGeom_Array1OfBezierCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > >::iterator":
        return _TColGeom.TColGeom_Array1OfBezierCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > >::iterator":
        return _TColGeom.TColGeom_Array1OfBezierCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfBezierCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfBezierCurve_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_Array1OfBezierCurve_swiginit(self, _TColGeom.new_TColGeom_Array1OfBezierCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom_BezierCurve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBezierCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBezierCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfBezierCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom_BezierCurve > > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom_BezierCurve > const &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_BezierCurve > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_BezierCurve > const &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_BezierCurve > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BezierCurve > const &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BezierCurve > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_BezierCurve > &":
        return _TColGeom.TColGeom_Array1OfBezierCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_BezierCurve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfBezierCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom.TColGeom_Array1OfBezierCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array1OfBezierCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom_Array1OfBezierCurve in _TColGeom:
_TColGeom.TColGeom_Array1OfBezierCurve_swigregister(TColGeom_Array1OfBezierCurve)

class TColGeom_Array1OfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom_Curve > >::iterator":
        return _TColGeom.TColGeom_Array1OfCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom_Curve > >::iterator":
        return _TColGeom.TColGeom_Array1OfCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom_Curve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom_Curve > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_Array1OfCurve_swiginit(self, _TColGeom.new_TColGeom_Array1OfCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom_Curve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom_Curve > > &":
        return _TColGeom.TColGeom_Array1OfCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom_Curve > > &":
        return _TColGeom.TColGeom_Array1OfCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom_Curve > > &":
        return _TColGeom.TColGeom_Array1OfCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_Array1OfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_Array1OfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_Array1OfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_Array1OfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_Array1OfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_Array1OfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_Array1OfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_Curve > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom.TColGeom_Array1OfCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array1OfCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom_Array1OfCurve in _TColGeom:
_TColGeom.TColGeom_Array1OfCurve_swigregister(TColGeom_Array1OfCurve)

class TColGeom_Array1OfSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom_Surface > >::iterator":
        return _TColGeom.TColGeom_Array1OfSurface_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom_Surface > >::iterator":
        return _TColGeom.TColGeom_Array1OfSurface_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom_Surface > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfSurface_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom_Surface > >::const_iterator":
        return _TColGeom.TColGeom_Array1OfSurface_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_Array1OfSurface_swiginit(self, _TColGeom.new_TColGeom_Array1OfSurface(*args))

    def Init(self, theValue: "opencascade::handle< Geom_Surface > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfSurface_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfSurface_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfSurface_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfSurface_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfSurface_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array1OfSurface_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfSurface_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array1OfSurface_IsAllocated(self)

    def Assign(self, theOther: "TColGeom_Array1OfSurface") -> "NCollection_Array1< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array1OfSurface_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array1OfSurface") -> "NCollection_Array1< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array1OfSurface_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array1OfSurface_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_Array1OfSurface_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array1OfSurface_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_Array1OfSurface_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array1OfSurface_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_Array1OfSurface_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array1OfSurface_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array1OfSurface___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_Surface > const &") -> "void":
        return _TColGeom.TColGeom_Array1OfSurface_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom.TColGeom_Array1OfSurface_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array1OfSurface

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom_Array1OfSurface in _TColGeom:
_TColGeom.TColGeom_Array1OfSurface_swigregister(TColGeom_Array1OfSurface)

class TColGeom_Array2OfBezierSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_Array2OfBezierSurface_swiginit(self, _TColGeom.new_TColGeom_Array2OfBezierSurface(*args))

    def Init(self, theValue: "opencascade::handle< Geom_BezierSurface > const &") -> "void":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Length(self)

    def NbRows(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_NbRows(self)

    def NbColumns(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_NbColumns(self)

    def RowLength(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_RowLength(self)

    def ColLength(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_ColLength(self)

    def LowerRow(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_LowerRow(self)

    def UpperRow(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_UpperRow(self)

    def LowerCol(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_LowerCol(self)

    def UpperCol(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfBezierSurface_UpperCol(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array2OfBezierSurface_IsDeletable(self)

    def Assign(self, theOther: "TColGeom_Array2OfBezierSurface") -> "NCollection_Array2< opencascade::handle< Geom_BezierSurface > > &":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array2OfBezierSurface") -> "NCollection_Array2< opencascade::handle< Geom_BezierSurface > > &":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array2< opencascade::handle< Geom_BezierSurface > > &":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Set(self, *args)

    def Value(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< Geom_BezierSurface > const &":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Value(self, theRow, theCol)

    def ChangeValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< Geom_BezierSurface > &":
        return _TColGeom.TColGeom_Array2OfBezierSurface_ChangeValue(self, theRow, theCol)

    def __call__(self, *args) -> "opencascade::handle< Geom_BezierSurface > &":
        return _TColGeom.TColGeom_Array2OfBezierSurface___call__(self, *args)

    def SetValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const", theItem: "opencascade::handle< Geom_BezierSurface > const &") -> "void":
        return _TColGeom.TColGeom_Array2OfBezierSurface_SetValue(self, theRow, theCol, theItem)

    def Resize(self, theRowLower: "Standard_Integer", theRowUpper: "Standard_Integer", theColLower: "Standard_Integer", theColUpper: "Standard_Integer", theToCopyData: "Standard_Boolean") -> "void":
        return _TColGeom.TColGeom_Array2OfBezierSurface_Resize(self, theRowLower, theRowUpper, theColLower, theColUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array2OfBezierSurface

# Register TColGeom_Array2OfBezierSurface in _TColGeom:
_TColGeom.TColGeom_Array2OfBezierSurface_swigregister(TColGeom_Array2OfBezierSurface)

class TColGeom_Array2OfSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_Array2OfSurface_swiginit(self, _TColGeom.new_TColGeom_Array2OfSurface(*args))

    def Init(self, theValue: "opencascade::handle< Geom_Surface > const &") -> "void":
        return _TColGeom.TColGeom_Array2OfSurface_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_Length(self)

    def NbRows(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_NbRows(self)

    def NbColumns(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_NbColumns(self)

    def RowLength(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_RowLength(self)

    def ColLength(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_ColLength(self)

    def LowerRow(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_LowerRow(self)

    def UpperRow(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_UpperRow(self)

    def LowerCol(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_LowerCol(self)

    def UpperCol(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_Array2OfSurface_UpperCol(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_Array2OfSurface_IsDeletable(self)

    def Assign(self, theOther: "TColGeom_Array2OfSurface") -> "NCollection_Array2< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array2OfSurface_Assign(self, theOther)

    def Move(self, theOther: "TColGeom_Array2OfSurface") -> "NCollection_Array2< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array2OfSurface_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array2< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_Array2OfSurface_Set(self, *args)

    def Value(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_Array2OfSurface_Value(self, theRow, theCol)

    def ChangeValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array2OfSurface_ChangeValue(self, theRow, theCol)

    def __call__(self, *args) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_Array2OfSurface___call__(self, *args)

    def SetValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const", theItem: "opencascade::handle< Geom_Surface > const &") -> "void":
        return _TColGeom.TColGeom_Array2OfSurface_SetValue(self, theRow, theCol, theItem)

    def Resize(self, theRowLower: "Standard_Integer", theRowUpper: "Standard_Integer", theColLower: "Standard_Integer", theColUpper: "Standard_Integer", theToCopyData: "Standard_Boolean") -> "void":
        return _TColGeom.TColGeom_Array2OfSurface_Resize(self, theRowLower, theRowUpper, theColLower, theColUpper, theToCopyData)
    __swig_destroy__ = _TColGeom.delete_TColGeom_Array2OfSurface

# Register TColGeom_Array2OfSurface in _TColGeom:
_TColGeom.TColGeom_Array2OfSurface_swigregister(TColGeom_Array2OfSurface)

class TColGeom_SequenceOfBoundedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > >::iterator":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > >::iterator":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_SequenceOfBoundedCurve_swiginit(self, _TColGeom.new_TColGeom_SequenceOfBoundedCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom_BoundedCurve > > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom_SequenceOfBoundedCurve") -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom_BoundedCurve > const &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_BoundedCurve > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_BoundedCurve > const &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_BoundedCurve > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BoundedCurve > const &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_BoundedCurve > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_BoundedCurve > &":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_BoundedCurve > const &") -> "void":
        return _TColGeom.TColGeom_SequenceOfBoundedCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom.delete_TColGeom_SequenceOfBoundedCurve

    def __len__(self):
        return self.Size()


# Register TColGeom_SequenceOfBoundedCurve in _TColGeom:
_TColGeom.TColGeom_SequenceOfBoundedCurve_swigregister(TColGeom_SequenceOfBoundedCurve)

def TColGeom_SequenceOfBoundedCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom.TColGeom_SequenceOfBoundedCurve_delNode(theNode, theAl)

class TColGeom_SequenceOfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom_Curve > >::iterator":
        return _TColGeom.TColGeom_SequenceOfCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom_Curve > >::iterator":
        return _TColGeom.TColGeom_SequenceOfCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom_Curve > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom_Curve > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_SequenceOfCurve_swiginit(self, _TColGeom.new_TColGeom_SequenceOfCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_SequenceOfCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom_Curve > > &":
        return _TColGeom.TColGeom_SequenceOfCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom_Curve > > &":
        return _TColGeom.TColGeom_SequenceOfCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom_SequenceOfCurve") -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_SequenceOfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_SequenceOfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_SequenceOfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_SequenceOfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Curve > const &":
        return _TColGeom.TColGeom_SequenceOfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_SequenceOfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_Curve > &":
        return _TColGeom.TColGeom_SequenceOfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_Curve > const &") -> "void":
        return _TColGeom.TColGeom_SequenceOfCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom.delete_TColGeom_SequenceOfCurve

    def __len__(self):
        return self.Size()


# Register TColGeom_SequenceOfCurve in _TColGeom:
_TColGeom.TColGeom_SequenceOfCurve_swigregister(TColGeom_SequenceOfCurve)

def TColGeom_SequenceOfCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom.TColGeom_SequenceOfCurve_delNode(theNode, theAl)

class TColGeom_SequenceOfSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom_Surface > >::iterator":
        return _TColGeom.TColGeom_SequenceOfSurface_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom_Surface > >::iterator":
        return _TColGeom.TColGeom_SequenceOfSurface_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom_Surface > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfSurface_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom_Surface > >::const_iterator":
        return _TColGeom.TColGeom_SequenceOfSurface_cend(self)

    def __init__(self, *args):
        _TColGeom.TColGeom_SequenceOfSurface_swiginit(self, _TColGeom.new_TColGeom_SequenceOfSurface(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfSurface_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfSurface_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfSurface_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom.TColGeom_SequenceOfSurface_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom.TColGeom_SequenceOfSurface_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom_SequenceOfSurface") -> "NCollection_Sequence< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_SequenceOfSurface_Assign(self, theOther)

    def Set(self, theOther: "TColGeom_SequenceOfSurface") -> "NCollection_Sequence< opencascade::handle< Geom_Surface > > &":
        return _TColGeom.TColGeom_SequenceOfSurface_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom_SequenceOfSurface") -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_SequenceOfSurface_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_SequenceOfSurface_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_SequenceOfSurface_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_SequenceOfSurface_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > const &":
        return _TColGeom.TColGeom_SequenceOfSurface_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_SequenceOfSurface_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom_Surface > &":
        return _TColGeom.TColGeom_SequenceOfSurface___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom_Surface > const &") -> "void":
        return _TColGeom.TColGeom_SequenceOfSurface_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom.delete_TColGeom_SequenceOfSurface

    def __len__(self):
        return self.Size()


# Register TColGeom_SequenceOfSurface in _TColGeom:
_TColGeom.TColGeom_SequenceOfSurface_swigregister(TColGeom_SequenceOfSurface)

def TColGeom_SequenceOfSurface_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom.TColGeom_SequenceOfSurface_delNode(theNode, theAl)

class TColGeom_HArray1OfSurface(TColGeom_Array1OfSurface, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HArray1OfSurface_swiginit(self, _TColGeom.new_TColGeom_HArray1OfSurface(*args))

    def Array1(self) -> "TColGeom_Array1OfSurface const &":
        return _TColGeom.TColGeom_HArray1OfSurface_Array1(self)

    def ChangeArray1(self) -> "TColGeom_Array1OfSurface &":
        return _TColGeom.TColGeom_HArray1OfSurface_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HArray1OfSurface_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HArray1OfSurface

# Register TColGeom_HArray1OfSurface in _TColGeom:
_TColGeom.TColGeom_HArray1OfSurface_swigregister(TColGeom_HArray1OfSurface)

class TColGeom_HArray1OfBezierCurve(TColGeom_Array1OfBezierCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HArray1OfBezierCurve_swiginit(self, _TColGeom.new_TColGeom_HArray1OfBezierCurve(*args))

    def Array1(self) -> "TColGeom_Array1OfBezierCurve const &":
        return _TColGeom.TColGeom_HArray1OfBezierCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom_Array1OfBezierCurve &":
        return _TColGeom.TColGeom_HArray1OfBezierCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HArray1OfBezierCurve_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HArray1OfBezierCurve

# Register TColGeom_HArray1OfBezierCurve in _TColGeom:
_TColGeom.TColGeom_HArray1OfBezierCurve_swigregister(TColGeom_HArray1OfBezierCurve)

class TColGeom_HArray1OfBSplineCurve(TColGeom_Array1OfBSplineCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HArray1OfBSplineCurve_swiginit(self, _TColGeom.new_TColGeom_HArray1OfBSplineCurve(*args))

    def Array1(self) -> "TColGeom_Array1OfBSplineCurve const &":
        return _TColGeom.TColGeom_HArray1OfBSplineCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom_Array1OfBSplineCurve &":
        return _TColGeom.TColGeom_HArray1OfBSplineCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HArray1OfBSplineCurve_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HArray1OfBSplineCurve

# Register TColGeom_HArray1OfBSplineCurve in _TColGeom:
_TColGeom.TColGeom_HArray1OfBSplineCurve_swigregister(TColGeom_HArray1OfBSplineCurve)

class TColGeom_HArray1OfCurve(TColGeom_Array1OfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HArray1OfCurve_swiginit(self, _TColGeom.new_TColGeom_HArray1OfCurve(*args))

    def Array1(self) -> "TColGeom_Array1OfCurve const &":
        return _TColGeom.TColGeom_HArray1OfCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom_Array1OfCurve &":
        return _TColGeom.TColGeom_HArray1OfCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HArray1OfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HArray1OfCurve

# Register TColGeom_HArray1OfCurve in _TColGeom:
_TColGeom.TColGeom_HArray1OfCurve_swigregister(TColGeom_HArray1OfCurve)

class TColGeom_HArray2OfSurface(TColGeom_Array2OfSurface, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HArray2OfSurface_swiginit(self, _TColGeom.new_TColGeom_HArray2OfSurface(*args))

    def Array2(self) -> "TColGeom_Array2OfSurface const &":
        return _TColGeom.TColGeom_HArray2OfSurface_Array2(self)

    def ChangeArray2(self) -> "TColGeom_Array2OfSurface &":
        return _TColGeom.TColGeom_HArray2OfSurface_ChangeArray2(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HArray2OfSurface_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HArray2OfSurface

# Register TColGeom_HArray2OfSurface in _TColGeom:
_TColGeom.TColGeom_HArray2OfSurface_swigregister(TColGeom_HArray2OfSurface)

class TColGeom_HSequenceOfBoundedCurve(TColGeom_SequenceOfBoundedCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HSequenceOfBoundedCurve_swiginit(self, _TColGeom.new_TColGeom_HSequenceOfBoundedCurve(*args))

    def Sequence(self) -> "TColGeom_SequenceOfBoundedCurve const &":
        return _TColGeom.TColGeom_HSequenceOfBoundedCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom.TColGeom_HSequenceOfBoundedCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom_SequenceOfBoundedCurve &":
        return _TColGeom.TColGeom_HSequenceOfBoundedCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HSequenceOfBoundedCurve_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HSequenceOfBoundedCurve

# Register TColGeom_HSequenceOfBoundedCurve in _TColGeom:
_TColGeom.TColGeom_HSequenceOfBoundedCurve_swigregister(TColGeom_HSequenceOfBoundedCurve)

class TColGeom_HSequenceOfCurve(TColGeom_SequenceOfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom.TColGeom_HSequenceOfCurve_swiginit(self, _TColGeom.new_TColGeom_HSequenceOfCurve(*args))

    def Sequence(self) -> "TColGeom_SequenceOfCurve const &":
        return _TColGeom.TColGeom_HSequenceOfCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom.TColGeom_HSequenceOfCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom_SequenceOfCurve &":
        return _TColGeom.TColGeom_HSequenceOfCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom_HSequenceOfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom.delete_TColGeom_HSequenceOfCurve

# Register TColGeom_HSequenceOfCurve in _TColGeom:
_TColGeom.TColGeom_HSequenceOfCurve_swigregister(TColGeom_HSequenceOfCurve)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Intrv module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intrv.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Intrv
else:
    import _Intrv

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Intrv.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Intrv.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Intrv.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Intrv.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Intrv.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Intrv.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Intrv.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Intrv.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Intrv.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Intrv.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Intrv.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Intrv.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Intrv.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Intrv.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Intrv.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Intrv.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Intrv.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Intrv:
_Intrv.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Intrv.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection

from enum import IntEnum
from OCC.Core.Exception import *

Intrv_Before = _Intrv.Intrv_Before
Intrv_JustBefore = _Intrv.Intrv_JustBefore
Intrv_OverlappingAtStart = _Intrv.Intrv_OverlappingAtStart
Intrv_JustEnclosingAtEnd = _Intrv.Intrv_JustEnclosingAtEnd
Intrv_Enclosing = _Intrv.Intrv_Enclosing
Intrv_JustOverlappingAtStart = _Intrv.Intrv_JustOverlappingAtStart
Intrv_Similar = _Intrv.Intrv_Similar
Intrv_JustEnclosingAtStart = _Intrv.Intrv_JustEnclosingAtStart
Intrv_Inside = _Intrv.Intrv_Inside
Intrv_JustOverlappingAtEnd = _Intrv.Intrv_JustOverlappingAtEnd
Intrv_OverlappingAtEnd = _Intrv.Intrv_OverlappingAtEnd
Intrv_JustAfter = _Intrv.Intrv_JustAfter
Intrv_After = _Intrv.Intrv_After


class Intrv_Position(IntEnum):
	Intrv_Before = 0
	Intrv_JustBefore = 1
	Intrv_OverlappingAtStart = 2
	Intrv_JustEnclosingAtEnd = 3
	Intrv_Enclosing = 4
	Intrv_JustOverlappingAtStart = 5
	Intrv_Similar = 6
	Intrv_JustEnclosingAtStart = 7
	Intrv_Inside = 8
	Intrv_JustOverlappingAtEnd = 9
	Intrv_OverlappingAtEnd = 10
	Intrv_JustAfter = 11
	Intrv_After = 12
Intrv_Before = Intrv_Position.Intrv_Before
Intrv_JustBefore = Intrv_Position.Intrv_JustBefore
Intrv_OverlappingAtStart = Intrv_Position.Intrv_OverlappingAtStart
Intrv_JustEnclosingAtEnd = Intrv_Position.Intrv_JustEnclosingAtEnd
Intrv_Enclosing = Intrv_Position.Intrv_Enclosing
Intrv_JustOverlappingAtStart = Intrv_Position.Intrv_JustOverlappingAtStart
Intrv_Similar = Intrv_Position.Intrv_Similar
Intrv_JustEnclosingAtStart = Intrv_Position.Intrv_JustEnclosingAtStart
Intrv_Inside = Intrv_Position.Intrv_Inside
Intrv_JustOverlappingAtEnd = Intrv_Position.Intrv_JustOverlappingAtEnd
Intrv_OverlappingAtEnd = Intrv_Position.Intrv_OverlappingAtEnd
Intrv_JustAfter = Intrv_Position.Intrv_JustAfter
Intrv_After = Intrv_Position.Intrv_After

class Intrv_SequenceOfInterval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Intrv_Interval >::iterator":
        return _Intrv.Intrv_SequenceOfInterval_begin(self)

    def end(self) -> "NCollection_Sequence< Intrv_Interval >::iterator":
        return _Intrv.Intrv_SequenceOfInterval_end(self)

    def cbegin(self) -> "NCollection_Sequence< Intrv_Interval >::const_iterator":
        return _Intrv.Intrv_SequenceOfInterval_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Intrv_Interval >::const_iterator":
        return _Intrv.Intrv_SequenceOfInterval_cend(self)

    def __init__(self, *args):
        _Intrv.Intrv_SequenceOfInterval_swiginit(self, _Intrv.new_Intrv_SequenceOfInterval(*args))

    def Size(self) -> "Standard_Integer":
        return _Intrv.Intrv_SequenceOfInterval_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Intrv.Intrv_SequenceOfInterval_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Intrv.Intrv_SequenceOfInterval_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Intrv.Intrv_SequenceOfInterval_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Intrv.Intrv_SequenceOfInterval_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Intrv.Intrv_SequenceOfInterval_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Clear(self, theAllocator)

    def Assign(self, theOther: "Intrv_SequenceOfInterval") -> "NCollection_Sequence< Intrv_Interval > &":
        return _Intrv.Intrv_SequenceOfInterval_Assign(self, theOther)

    def Set(self, theOther: "Intrv_SequenceOfInterval") -> "NCollection_Sequence< Intrv_Interval > &":
        return _Intrv.Intrv_SequenceOfInterval_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Intrv.Intrv_SequenceOfInterval_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Intrv_SequenceOfInterval") -> "void":
        return _Intrv.Intrv_SequenceOfInterval_Split(self, theIndex, theSeq)

    def First(self) -> "Intrv_Interval const &":
        return _Intrv.Intrv_SequenceOfInterval_First(self)

    def ChangeFirst(self) -> "Intrv_Interval &":
        return _Intrv.Intrv_SequenceOfInterval_ChangeFirst(self)

    def Last(self) -> "Intrv_Interval const &":
        return _Intrv.Intrv_SequenceOfInterval_Last(self)

    def ChangeLast(self) -> "Intrv_Interval &":
        return _Intrv.Intrv_SequenceOfInterval_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Intrv_Interval const &":
        return _Intrv.Intrv_SequenceOfInterval_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Intrv_Interval &":
        return _Intrv.Intrv_SequenceOfInterval_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Intrv_Interval &":
        return _Intrv.Intrv_SequenceOfInterval___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Intrv_Interval") -> "void":
        return _Intrv.Intrv_SequenceOfInterval_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Intrv.delete_Intrv_SequenceOfInterval

    def __len__(self):
        return self.Size()


# Register Intrv_SequenceOfInterval in _Intrv:
_Intrv.Intrv_SequenceOfInterval_swigregister(Intrv_SequenceOfInterval)

def Intrv_SequenceOfInterval_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Intrv.Intrv_SequenceOfInterval_delNode(theNode, theAl)

class Intrv_Interval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Start: float
        End: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Start: float
        TolStart: Standard_ShortReal
        End: float
        TolEnd: Standard_ShortReal

        Returns
        -------
        None

        """
        _Intrv.Intrv_Interval_swiginit(self, _Intrv.new_Intrv_Interval(*args))

    def Bounds(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TolStart: Standard_ShortReal
        TolEnd: Standard_ShortReal

        Returns
        -------
        Start: float
        End: float

        """
        return _Intrv.Intrv_Interval_Bounds(self, *args)

    def CutAtEnd(self, *args) -> "void":
        r"""
        <-----****+****  old one **+**------> tool for cutting <<< <<< <-----****+****  result.

        Parameters
        ----------
        End: float
        TolEnd: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_CutAtEnd(self, *args)

    def CutAtStart(self, *args) -> "void":
        r"""
        ****+****-----------> old one <----------**+** tool for cutting >>> >>> ****+****-----------> result.

        Parameters
        ----------
        Start: float
        TolStart: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_CutAtStart(self, *args)

    def End(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Intrv.Intrv_Interval_End(self, *args)

    def FuseAtEnd(self, *args) -> "void":
        r"""
        <---------------------****+**** old one <-----------------**+**  new one to fuse >>> >>> <---------------------****+**** result.

        Parameters
        ----------
        End: float
        TolEnd: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_FuseAtEnd(self, *args)

    def FuseAtStart(self, *args) -> "void":
        r"""
        ****+****--------------------> old one ****+****------------------------> new one to fuse <<< <<< ****+****------------------------> result.

        Parameters
        ----------
        Start: float
        TolStart: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_FuseAtStart(self, *args)

    def IsAfter(self, *args) -> "Standard_Boolean":
        r"""
        True if me is after other **-----------**** me ***----------------**  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsAfter(self, *args)

    def IsBefore(self, *args) -> "Standard_Boolean":
        r"""
        True if me is before other ***----------------**  me **-----------**** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsBefore(self, *args)

    def IsEnclosing(self, *args) -> "Standard_Boolean":
        r"""
        True if me is enclosing other ***----------------------------**** me ***------------------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsEnclosing(self, *args)

    def IsInside(self, *args) -> "Standard_Boolean":
        r"""
        True if me is inside other **-----------****  me ***--------------------------**  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsInside(self, *args)

    def IsJustAfter(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just after other ****-------****  me ***-----------**  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustAfter(self, *args)

    def IsJustBefore(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just before other ***--------****   me ***-----------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustBefore(self, *args)

    def IsJustEnclosingAtEnd(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just enclosing other at end ***----------------------------**** me ***-----------------****  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustEnclosingAtEnd(self, *args)

    def IsJustEnclosingAtStart(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just enclosing other at start ***---------------------------**** me ***------------------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustEnclosingAtStart(self, *args)

    def IsJustOverlappingAtEnd(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just overlapping other at end ***-----------*  me ***------------------------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustOverlappingAtEnd(self, *args)

    def IsJustOverlappingAtStart(self, *args) -> "Standard_Boolean":
        r"""
        True if me is just overlapping other at start ***-----------***  me ***------------------------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsJustOverlappingAtStart(self, *args)

    def IsOverlappingAtEnd(self, *args) -> "Standard_Boolean":
        r"""
        True if me is overlapping other at end ***-----------** me ***---------------***  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsOverlappingAtEnd(self, *args)

    def IsOverlappingAtStart(self, *args) -> "Standard_Boolean":
        r"""
        True if me is overlapping other at start ***---------------***  me ***-----------** other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsOverlappingAtStart(self, *args)

    def IsProbablyEmpty(self, *args) -> "Standard_Boolean":
        r"""
        True if mystart+mytolstart > myend-mytolend or if myend+mytolend > mystart-mytolstart.

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsProbablyEmpty(self, *args)

    def IsSimilar(self, *args) -> "Standard_Boolean":
        r"""
        True if me and other have the same bounds *----------------***  me ***-----------------**  other.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        bool

        """
        return _Intrv.Intrv_Interval_IsSimilar(self, *args)

    def Position(self, *args) -> "Intrv_Position":
        r"""
        True if me is before other **-----------**** other ***-----*   before ***------------*  justbefore ***-----------------*  overlappingatstart ***--------------------------*  justenclosingatend ***-------------------------------------* enclosing ***----*  justoverlappingatstart ***-------------*  similar ***------------------------* justenclosingatstart ***-*  inside ***------*  justoverlappingatend ***-----------------* overlappingatend ***--------* justafter ***---* after.

        Parameters
        ----------
        Other: Intrv_Interval

        Returns
        -------
        Intrv_Position

        """
        return _Intrv.Intrv_Interval_Position(self, *args)

    def SetEnd(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        End: float
        TolEnd: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_SetEnd(self, *args)

    def SetStart(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Start: float
        TolStart: Standard_ShortReal

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Interval_SetStart(self, *args)

    def Start(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _Intrv.Intrv_Interval_Start(self, *args)

    def TolEnd(self, *args) -> "Standard_ShortReal":
        r"""
        No available documentation.

        Returns
        -------
        Standard_ShortReal

        """
        return _Intrv.Intrv_Interval_TolEnd(self, *args)

    def TolStart(self, *args) -> "Standard_ShortReal":
        r"""
        No available documentation.

        Returns
        -------
        Standard_ShortReal

        """
        return _Intrv.Intrv_Interval_TolStart(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Intrv.delete_Intrv_Interval

# Register Intrv_Interval in _Intrv:
_Intrv.Intrv_Interval_swigregister(Intrv_Interval)

class Intrv_Intervals(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a void sequence of intervals.

        Returns
        -------
        None
        Creates a sequence of one interval.

        Parameters
        ----------
        Int: Intrv_Interval

        Returns
        -------
        None

        """
        _Intrv.Intrv_Intervals_swiginit(self, _Intrv.new_Intrv_Intervals(*args))

    def Intersect(self, *args) -> "void":
        r"""
        Intersects the intervals with the interval <tool>.

        Parameters
        ----------
        Tool: Intrv_Interval

        Returns
        -------
        None
        Intersects the intervals with the intervals in the sequence <tool>.

        Parameters
        ----------
        Tool: Intrv_Intervals

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Intervals_Intersect(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Intrv.Intrv_Intervals_NbIntervals(self, *args)

    def Subtract(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Interval

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Intervals

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Intervals_Subtract(self, *args)

    def Unite(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Interval

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Intervals

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Intervals_Unite(self, *args)

    def Value(self, *args) -> "Intrv_Interval const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intrv_Interval

        """
        return _Intrv.Intrv_Intervals_Value(self, *args)

    def XUnite(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Interval

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tool: Intrv_Intervals

        Returns
        -------
        None

        """
        return _Intrv.Intrv_Intervals_XUnite(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Intrv.delete_Intrv_Intervals

# Register Intrv_Intervals in _Intrv:
_Intrv.Intrv_Intervals_swigregister(Intrv_Intervals)





